==> zio-aws-batch_2.13-5.17.124.1-sources.jar: zio/aws/batch/model/KeyValuesPair.scala <==
package zio.aws.batch.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class KeyValuesPair(
    name: Option[String] = None,
    values: Option[Iterable[String]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.batch.model.KeyValuesPair = {
    import KeyValuesPair.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.batch.model.KeyValuesPair
      .builder()
      .optionallyWith(name.map(value => value: java.lang.String))(_.name)
      .optionallyWith(
        values.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.values)
      .build()
  }
  def asReadOnly: zio.aws.batch.model.KeyValuesPair.ReadOnly =
    zio.aws.batch.model.KeyValuesPair.wrap(buildAwsValue())
}
object KeyValuesPair {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.batch.model.KeyValuesPair
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.batch.model.KeyValuesPair = zio.aws.batch.model
      .KeyValuesPair(name.map(value => value), values.map(value => value))
    def name: Option[String]
    def values: Option[List[String]]
    def getName: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("name", name)
    def getValues: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("values", values)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.batch.model.KeyValuesPair
  ) extends zio.aws.batch.model.KeyValuesPair.ReadOnly {
    override val name: Option[String] =
      scala.Option(impl.name()).map(value => value: String)
    override val values: Option[List[String]] = scala
      .Option(impl.values())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.batch.model.KeyValuesPair
  ): zio.aws.batch.model.KeyValuesPair.ReadOnly = new Wrapper(impl)
}

==> zio-aws-batch_2.13-5.17.197.1-sources.jar: zio/aws/batch/model/KeyValuesPair.scala <==
package zio.aws.batch.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class KeyValuesPair(
    name: Optional[String] = Optional.Absent,
    values: Optional[Iterable[String]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.batch.model.KeyValuesPair = {
    import KeyValuesPair.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.batch.model.KeyValuesPair
      .builder()
      .optionallyWith(name.map(value => value: java.lang.String))(_.name)
      .optionallyWith(
        values.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.values)
      .build()
  }
  def asReadOnly: zio.aws.batch.model.KeyValuesPair.ReadOnly =
    zio.aws.batch.model.KeyValuesPair.wrap(buildAwsValue())
}
object KeyValuesPair {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.batch.model.KeyValuesPair
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.batch.model.KeyValuesPair = zio.aws.batch.model
      .KeyValuesPair(name.map(value => value), values.map(value => value))
    def name: Optional[String]
    def values: Optional[List[String]]
    def getName: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("name", name)
    def getValues: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("values", values)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.batch.model.KeyValuesPair
  ) extends zio.aws.batch.model.KeyValuesPair.ReadOnly {
    override val name: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value => value: String)
    override val values: Optional[List[String]] = zio.aws.core.internal
      .optionalFromNullable(impl.values())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.batch.model.KeyValuesPair
  ): zio.aws.batch.model.KeyValuesPair.ReadOnly = new Wrapper(impl)
}
